#include <iostream>
#include <vector>
#include <string>
#include <algorithm>
#include <unordered_map>
#include <unordered_set>
#include <set>

using namespace std;
using ll = long long;

const int mod = 1e9 + 7;

struct node {
	ll cbl = 0, cbr = 0, fbb = -1, lbb = -1, ban = false, fsym = -1, lsym = -1, lch = 1, rch = 1, sz = 1;

	node() {}

	node(ll sz) : sz(sz) {}
};

node merge(node a, node b) {
	if (a.sz == -1) return b;
	if (b.sz == -1) return a;

	node ans;
	ans.sz = a.sz + b.sz;

	ans.cbl = a.cbl;
	if (a.cbl == a.sz) ans.cbl += b.cbl;

	ans.cbr = b.cbr;
	if (b.cbr == b.sz) ans.cbr += a.cbr;

	ans.fsym = a.fsym;

	ans.lsym = b.lsym;

	ans.lch = a.lch;
	if (a.lch == a.sz && a.lsym != b.fsym) ans.lch += b.lch;

	ans.rch = b.rch;
	if (b.rch == a.sz && a.lsym != b.fsym) ans.rch += a.rch;

	ans.fbb = a.fbb;
	if (ans.fbb == -1 && a.lsym == 'b' && b.fsym == 'b') ans.fbb = a.sz - 1;
	if (ans.fbb == -1) ans.fbb = b.fbb;

	ans.lbb = b.lbb;
	if (ans.lbb == -1 && a.lsym == 'b' && b.fsym == 'b') ans.lbb = b.sz - 1;
	if (ans.lbb == -1) ans.lbb = a.lbb;

	ans.ban = a.ban || b.ban;
	bool atmid = false;
	if (a.lsym == 'b' && b.fsym == 'b') atmid = true;
	if (a.lbb == 0) atmid = true;
	if (b.fbb == 0) atmid = true;
	if (atmid && b.lch >= b.fbb && b.fbb != -1) ans.ban = true;
	if (atmid && a.rch >= a.lbb && a.lbb != -1) ans.ban = true;
	if (a.lsym != b.fsym && a.rch >= a.lbb && b.lch >= b.fbb && a.lbb != -1 && b.fbb != -1) ans.ban = true;

	return ans;
}

struct segmentTree {
	vector<node> segTree;
	string str;

	void build(ll i, ll l, ll r) {
		if (r - l == 1) {
			segTree[i].fsym = str[l];
			segTree[i].lsym = str[l];
			if (str[l] == 'b') {
				segTree[i].cbl = 1;
				segTree[i].cbr = 1;
			}
			return;
		}
		ll m = (l + r) / 2;
		build(i * 2 + 1, l, m);
		build(i * 2 + 2, m, r);
		segTree[i] = merge(segTree[i * 2 + 1], segTree[i * 2 + 2]);
	}

	segmentTree(string str) : str(str) {
		ll n = str.size();
		segTree.resize(4 * n);
		build(0, 0, n);
	}

	node get(ll i, ll l, ll r, ll ql, ll qr) {
		if (l >= ql && r <= qr) return segTree[i];
		if (l >= qr || r <= ql) return node(-1);
		ll m = (l + r) / 2;
		return merge(get(i * 2 + 1, l, m, ql, qr), get(i * 2 + 2, m, r, ql, qr));
	}

	void replace(ll i, ll l, ll r, ll id) {
		if (r - l == 1) {
			if (str[l] == 'a') str[l] = 'b';
			else str[l] = 'a';
			segTree[i].fsym = str[l];
			segTree[i].lsym = str[l];
			if (str[l] == 'b') {
				segTree[i].cbl = 1;
				segTree[i].cbr = 1;
			}
			return;
		}
		ll m = (l + r) / 2;
		if (id < m) replace(i * 2 + 1, l, m, id);
		else replace(i * 2 + 2, m, r, id);
		segTree[i] = merge(segTree[i * 2 + 1], segTree[i * 2 + 2]);
	}
};

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);

	ll n; cin >> n;
	string str; cin >> str;
	segmentTree st = str;
	ll q; cin >> q;
	while (q--) {
		ll type; cin >> type;
		if (type == 1) {
			ll id; cin >> id; id--;
			st.replace(0, 0, n, id);
		} else {
			ll l, r; cin >> l >> r; l--;
			node ans = st.get(0, 0, n, l, r);

			bool answer = !ans.ban;

			if (ans.fbb != -1 && ans.fsym == 'b' && ans.lch >= ans.fbb) answer = false;
			if (ans.lbb != -1 && ans.lsym == 'b' && ans.rch >= ans.lbb) answer = false;
			if (ans.fbb == -1 && ans.lch == ans.sz && ans.fsym == 'b' && ans.lsym == 'b') answer = false;

			if (answer) {
				cout << "YES" << endl;
			} else {
				cout << "NO" << endl;
			}
		}
	}
}