#include <bits/stdc++.h>

using namespace std;
using ll = long long;

#define S second
#define F first

const int mod = 1e9 + 7;

struct Cell {
    bool can[4];
    char l, r;
    Cell() {
        l = r = '?';
        can[0] = can[1] = can[2] = can[3] = false;
    }
    Cell operator+(const Cell& other) const {
        Cell res;
        if (r == '?') {
            for (int i = 0; i < 4; ++i) {
                res.can[i] = other.can[i];
            }
            res.l = other.l;
            res.r = other.r;
            return res;
        }
        if (other.r == '?') {
            for (int i = 0; i < 4; ++i) {
                res.can[i] = can[i];
            }
            res.l = l;
            res.r = r;
            return res;
        }
        res.can[0] = res.can[0] || (can[0] && other.can[0]);
        res.can[0] = res.can[0] || (can[2] && other.can[1] && r != other.l);
        res.can[1] = res.can[1] || (can[1] && other.can[0]);
        res.can[1] = res.can[1] || (can[3] && other.can[1] && r != other.l);
        res.can[2] = res.can[2] || (can[0] && other.can[2]);
        res.can[2] = res.can[2] || (can[2] && other.can[3] && r != other.l);
        res.can[3] = res.can[3] || (can[1] && other.can[2]);
        res.can[3] = res.can[3] || (can[3] && other.can[3] && r != other.l);
        res.l = l, res.r = other.r;
        return res;
    }
    ~Cell() {}
};

struct SegTree {
    int n, N;
    vector<Cell> st;
    SegTree() {}
    SegTree(int _n) {
        n = _n, N = 1;
        while (N < n) {
            N <<= 1;
        }
        st.resize(2 * N);
    }
    void build(const string& s) {
        for (int i = 0; i < n; ++i) {
            st[N + i].can[0] = (s[i] != 'b');
            st[N + i].can[1] = true;
            st[N + i].can[2] = true;
            st[N + i].l = st[N + i].r = s[i];
        }
        for (int v = N - 1; v > 0; --v) {
            st[v] = st[2 * v] + st[2 * v + 1];
        }
    }
    Cell query(int l, int r) {
        int vl = N + l, vr = N + r;
        Cell resL, resR;
        while (vl < vr) {
            if (vl & 1) {
                resL = resL + st[vl];
            }
            if ((vr ^ 1) & 1) {
                resR = st[vr] + resR;
            }
            vl = ((vl + 1) >> 1);
            vr = ((vr - 1) >> 1);
        }
        if (vl == vr) {
            resL = resL + st[vl];
        }
        return resL + resR;
    }
    void toggle(int i) {
        int v = N + i;
        char sym = 'a' + (st[v].can[0]);
        st[v].can[0] = (sym != 'b');
        st[v].l = st[v].r = sym;
        v >>= 1;
        while (v > 0) {
            st[v] = st[2 * v] + st[2 * v + 1];
            v >>= 1;
        }
    }
    ~SegTree() {}
};

void solve() {
    int n;
    cin >> n;
    string s;
    cin >> s;
    SegTree st(n);
    st.build(s);
    int q;
    cin >> q;
    while (q--) {
        int type;
        cin >> type;
        if (type == 1) {
            int i;
            cin >> i;
            --i;
            st.toggle(i);
        } else {
            int l, r;
            cin >> l >> r;
            --l, --r;
            Cell res = st.query(l, r);
            if (res.can[0]) {
                cout << "YES\n";
            } else {
                cout << "NO\n";
            }
        }
    }
}

int main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0); cout.tie(0);

    int t = 1;
    while (t--) {
        solve();
    }
    return 0;
}
